BytesTransferable class

Wraps raw bytes to be copied into a container.

The bytes are packed as a single file entry inside a tar archive and placed at the destination path within the container.

Example:

container.withCopyIntoContainer(
  BytesTransferable(Uint8List.fromList(utf8.encode('hello'))),
  '/app/hello.txt',
  0x1A4, // 0o644
);
Inheritance

Constructors

BytesTransferable(Uint8List bytes)
Creates a BytesTransferable from bytes.

Properties

bytes Uint8List
The raw content to place in the container.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited