bytes property

Uint8List bytes
final

The raw content to place in the container.

A defensive copy is made at construction time so that mutations to the original buffer after calling this constructor do not affect the transferred content.

Implementation

final Uint8List bytes;