operator < method

bool operator <(
  1. Object other
)

Returns true if this version is strictly less than other.

other may be a ComparableVersion or a String that will be parsed on the fly. Throws FormatException if other is a String that cannot be parsed as a three-part version.

Implementation

bool operator <(Object other) {
  if (other is ComparableVersion) {
    return compareTo(other) < 0;
  }
  return compareTo(ComparableVersion(other.toString())) < 0;
}