ContainerAddress class

A single IP address assigned to a container's secondary network interface.

Constructors

ContainerAddress({String? addr, int? prefixLen})
Creates a ContainerAddress with the given fields.
const
ContainerAddress.fromJson(Map<String, dynamic> json)
Deserialises from Docker's JSON representation.
factory

Properties

addr String?
IP address string.
final
hashCode int
The hash code for this object.
no setterinherited
prefixLen int?
Subnet prefix length.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited