ContainerBlkioDeviceRate class

A single entry in a blkio device I/O rate list.

Used for BlkioDeviceReadBps, BlkioDeviceWriteBps, BlkioDeviceReadIOps, and BlkioDeviceWriteIOps.

Constructors

ContainerBlkioDeviceRate({String? path, int? rate})
Creates a ContainerBlkioDeviceRate with the given fields.
const
ContainerBlkioDeviceRate.fromJson(Map<String, dynamic> json)
Deserialises from Docker's JSON representation.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
path String?
Device path on the host.
final
rate int?
Rate limit (bytes per second or I/O operations per second).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited