ContainerBlkioWeightDevice class

A single entry in the BlkioWeightDevice host-config list.

Constructors

ContainerBlkioWeightDevice({String? path, int? weight})
Creates a ContainerBlkioWeightDevice with the given fields.
const
ContainerBlkioWeightDevice.fromJson(Map<String, dynamic> json)
Deserialises from Docker's JSON representation.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
path String?
Device path on the host, e.g. '/dev/sda'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
weight int?
Relative I/O weight for the device (10–1000).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited