ContainerDeviceRequest class

A request for generic device access (e.g. GPU via the NVIDIA device plugin).

Constructors

ContainerDeviceRequest({String? driver, int? count, List<String>? deviceIDs, List<List<String>>? capabilities, Map<String, String>? options})
Creates a ContainerDeviceRequest with the given fields.
const
ContainerDeviceRequest.fromJson(Map<String, dynamic> json)
Deserialises from Docker's JSON representation.
factory

Properties

capabilities List<List<String>>?
Capability sets, e.g. [['gpu'], ['nvidia', 'compute']].
final
count int?
Number of devices to request (-1 for all).
final
deviceIDs List<String>?
Specific device IDs to request.
final
driver String?
Driver to use for the request (e.g. 'nvidia').
final
hashCode int
The hash code for this object.
no setterinherited
options Map<String, String>?
Driver-specific options.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited