ContainerGraphDriver class

The storage driver and its metadata for a container's writable layer.

Constructors

ContainerGraphDriver({String? name, Map<String, String>? data})
Creates a ContainerGraphDriver with the given fields.
const
ContainerGraphDriver.fromJson(Map<String, dynamic> json)
Deserialises from Docker's JSON representation.
factory

Properties

data Map<String, String>?
Driver-specific metadata (e.g. layer diff paths).
final
hashCode int
The hash code for this object.
no setterinherited
name String?
Storage driver name, e.g. 'overlay2'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited