ContainerHealth class

The aggregated health status of a container.

Populated only when the container has a HEALTHCHECK instruction.

Constructors

ContainerHealth({String? status, int? failingStreak, List<ContainerLog>? log})
Creates a ContainerHealth with the given fields.
const
ContainerHealth.fromJson(Map<String, dynamic> json)
Deserialises a ContainerHealth from Docker's JSON representation.
factory

Properties

failingStreak int?
Number of consecutive health-check failures since the last success.
final
hashCode int
The hash code for this object.
no setterinherited
log List<ContainerLog>?
The most recent health-check log entries, newest first.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
Overall health status string: 'healthy', 'unhealthy', or 'starting'.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited