ContainerIPAMConfig class

Static IP configuration for a network endpoint (IPAM).

Constructors

ContainerIPAMConfig({String? ipv4Address, String? ipv6Address, List<String>? linkLocalIPs})
Creates a ContainerIPAMConfig with the given fields.
const
ContainerIPAMConfig.fromJson(Map<String, dynamic> json)
Deserialises from Docker's JSON representation.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ipv4Address String?
Statically assigned IPv4 address.
final
ipv6Address String?
Statically assigned IPv6 address.
final
linkLocalIPs List<String>?
Link-local IP addresses.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited