ContainerImageOptions class

Options for an image-based mount.

Constructors

ContainerImageOptions({String? subpath})
Creates a ContainerImageOptions with the given fields.
const
ContainerImageOptions.fromJson(Map<String, dynamic> json)
Deserialises from Docker's JSON representation.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subpath String?
Sub-path within the image to mount.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited