ContainerIsNotRunning class

Thrown when an operation requires a running container but the container is not (or is no longer) in the running state.

Common triggers include calling DockerCompose.container when the requested service has exited, or calling DockerCompose.container without a service name when there is not exactly one running container.

Example:

try {
  final c = compose.container('web');
} on ContainerIsNotRunning catch (e) {
  print(e.message);
}
Implemented types

Constructors

ContainerIsNotRunning(String message)
Creates a ContainerIsNotRunning with the given message.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of which container is not running and why.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited