ContainerNetworkSettings class

The complete network configuration of a running container.

Returned as the NetworkSettings field in a container inspect response.

Constructors

ContainerNetworkSettings({String? bridge, String? sandboxID, bool? hairpinMode, String? linkLocalIPv6Address, int? linkLocalIPv6PrefixLen, Map<String, List<ContainerPortBinding>?>? ports, String? sandboxKey, List<ContainerAddress>? secondaryIPAddresses, List<ContainerAddress>? secondaryIPv6Addresses, String? endpointID, String? gateway, String? globalIPv6Address, int? globalIPv6PrefixLen, String? ipAddress, int? ipPrefixLen, String? ipv6Gateway, String? macAddress, Map<String, ContainerNetworkEndpoint>? networks})
Creates a ContainerNetworkSettings with the given fields.
const
ContainerNetworkSettings.fromJson(Map<String, dynamic> json)
Deserialises a ContainerNetworkSettings from Docker's JSON representation.
factory

Properties

bridge String?
Name of the default bridge network.
final
endpointID String?
Default network endpoint ID.
final
gateway String?
Default network gateway IP.
final
globalIPv6Address String?
Global IPv6 address on the default network.
final
globalIPv6PrefixLen int?
Prefix length of the global IPv6 address.
final
hairpinMode bool?
Whether hairpin NAT is enabled.
final
hashCode int
The hash code for this object.
no setterinherited
ipAddress String?
IPv4 address on the default network.
final
ipPrefixLen int?
Prefix length of the IPv4 address.
final
ipv6Gateway String?
IPv6 gateway on the default network.
final
linkLocalIPv6Address String?
Link-local IPv6 address.
final
linkLocalIPv6PrefixLen int?
Prefix length of the link-local IPv6 address.
final
macAddress String?
MAC address on the default network.
final
networks Map<String, ContainerNetworkEndpoint>?
Per-network connection details, keyed by network name.
final
ports Map<String, List<ContainerPortBinding>?>?
Published port bindings: container port spec → list of host bindings.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sandboxID String?
Sandbox ID (internal identifier for the network namespace).
final
sandboxKey String?
Sandbox key (path to the network namespace file).
final
secondaryIPAddresses List<ContainerAddress>?
Secondary IPv4 addresses.
final
secondaryIPv6Addresses List<ContainerAddress>?
Secondary IPv6 addresses.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited