ContainerPlatform class

The platform (OS and architecture) of a container image.

Constructors

ContainerPlatform({String? architecture, String? os, String? variant})
Creates a ContainerPlatform with the given fields.
const
ContainerPlatform.fromJson(Map<String, dynamic> json)
Deserialises a ContainerPlatform from Docker's JSON representation.
factory

Properties

architecture String?
CPU architecture string, e.g. 'amd64' or 'arm64'.
final
hashCode int
The hash code for this object.
no setterinherited
os String?
Operating system string, e.g. 'linux' or 'windows'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variant String?
Architecture variant, e.g. 'v8' for ARMv8.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited