ContainerPortBinding class

A single host-to-container port binding.

The Docker daemon maps a container port to an ephemeral host port. Multiple ContainerPortBinding entries can exist for the same container port (e.g. to bind on both 0.0.0.0 and :: for IPv4 + IPv6).

Constructors

ContainerPortBinding({String? hostIp, String? hostPort})
Creates a ContainerPortBinding with the given fields.
const
ContainerPortBinding.fromJson(Map<String, dynamic> json)
Deserialises from Docker's JSON representation.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hostIp String?
Host IP address to bind on, e.g. '0.0.0.0' or '127.0.0.1'.
final
hostPort String?
Ephemeral port number on the host, as a string (Docker's JSON format).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited