ContainerTmpfsOptions class

Options for a tmpfs (in-memory) mount.

Constructors

ContainerTmpfsOptions({int? sizeBytes, int? mode, List<List<String>>? options})
Creates a ContainerTmpfsOptions with the given fields.
const
ContainerTmpfsOptions.fromJson(Map<String, dynamic> json)
Deserialises from Docker's JSON representation.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
mode int?
Unix permission bits for the tmpfs root directory.
final
options List<List<String>>?
Additional mount options as key-value pairs.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes int?
Maximum size of the tmpfs in bytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited