ContainerUlimit class

A ulimit (resource limit) applied to the container.

Constructors

ContainerUlimit({String? name, int? soft, int? hard})
Creates a ContainerUlimit with the given fields.
const
ContainerUlimit.fromJson(Map<String, dynamic> json)
Deserialises from Docker's JSON representation.
factory

Properties

hard int?
Hard limit value.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
The ulimit type, e.g. 'nofile' or 'nproc'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
soft int?
Soft limit value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited