ContainerVolumeDriverConfig class

Driver configuration for a named volume.

Constructors

ContainerVolumeDriverConfig({String? name, Map<String, String>? options})
Creates a ContainerVolumeDriverConfig with the given fields.
const
ContainerVolumeDriverConfig.fromJson(Map<String, dynamic> json)
Deserialises from Docker's JSON representation.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
Volume driver name, e.g. 'local'.
final
options Map<String, String>?
Driver-specific options.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited