image property

String image
final

The Docker image name (including optional tag) used to create the container.

The TestcontainersConfiguration.hubImageNamePrefix is prepended in the constructor, so if a registry mirror is configured, all image names are automatically redirected.

Implementation

final String image;