wait method

Future<int> wait()

Blocks until the container stops and returns its exit code.

Useful for containers that are expected to run to completion (e.g. init or migration containers).

Throws ContainerStartException when called before start.

Implementation

Future<int> wait() async {
  return _dockerClient.waitContainer(_requireContainerId);
}