waitingFor method
Attaches a WaitStrategy that start will invoke after the container is running.
Returns this for chaining.
Implementation
DockerContainer waitingFor(WaitStrategy strategy) {
_waitStrategy = strategy;
return this;
}
Attaches a WaitStrategy that start will invoke after the container is running.
Returns this for chaining.
DockerContainer waitingFor(WaitStrategy strategy) {
_waitStrategy = strategy;
return this;
}