expectedExitCode property
The exit code that indicates the container is ready.
Defaults to 0 (success).
Implementation
final int expectedExitCode;
The exit code that indicates the container is ready.
Defaults to 0 (success).
final int expectedExitCode;