forResponsePredicate method

HttpWaitStrategy forResponsePredicate(
  1. bool predicate(
    1. String
    )
)

Adds an additional response body check on top of the status-code check.

The response body is decoded as a UTF-8 string and passed to predicate. Both the status-code check and predicate must pass for the container to be considered ready.

Returns this for chaining.

Implementation

HttpWaitStrategy forResponsePredicate(bool Function(String) predicate) {
  _responsePredicate = predicate;
  return this;
}