testMethod property
The HTTP method that will be used for each probe request.
Exposed for unit testing only — do not read from production code.
Implementation
@visibleForTesting
String get testMethod => _method;
The HTTP method that will be used for each probe request.
Exposed for unit testing only — do not read from production code.
@visibleForTesting
String get testMethod => _method;