withBody method
Sets a request body to include with each probe request.
Returns this for chaining.
Implementation
HttpWaitStrategy withBody(String body) {
_body = body;
return this;
}
Sets a request body to include with each probe request.
Returns this for chaining.
HttpWaitStrategy withBody(String body) {
_body = body;
return this;
}