create method

Future<Network> create()

Creates the Docker network and returns this.

Must be called before passing the network to any container. Stores the Docker-assigned id for use in subsequent connect and remove calls.

Implementation

Future<Network> create() async {
  _networkId = await _dockerClient.createNetwork(name);
  return this;
}