name property
The unique name assigned to this network.
Generated as a random UUID v4 to avoid collisions across concurrent test runs. The same name is used as the Docker network name.
Implementation
final String name;
The unique name assigned to this network.
Generated as a random UUID v4 to avoid collisions across concurrent test runs. The same name is used as the Docker network name.
final String name;