NoSuchPortExposed class
Thrown when a requested port is not exposed by the container.
Raised by ComposeContainer.publisher when no matching publisher can be
found for the requested port, host, or IP-version combination.
Example:
try {
final pub = container.publisher(byPort: 9999);
} on NoSuchPortExposed catch (e) {
print(e.message);
}
- Implemented types
Constructors
- NoSuchPortExposed(String message)
-
Creates a NoSuchPortExposed with the given
message.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited