PathTransferable class

Wraps a local FileSystemEntity (file or directory) to be copied into a container.

  • When path is a File, the file is packed as a single entry.
  • When path is a Directory, all files within the directory tree are packed recursively. The directory itself is placed at destination inside the archive.

Example:

container.withCopyIntoContainer(
  PathTransferable(File('/tmp/config.yaml')),
  '/etc/myapp/config.yaml',
  0x1A4,
);
Inheritance

Constructors

PathTransferable(FileSystemEntity path)
Creates a PathTransferable from path.

Properties

hashCode int
The hash code for this object.
no setterinherited
path FileSystemEntity
The local file or directory to copy into the container.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited