maxTries property
Maximum number of polling attempts before a wait strategy gives up.
Controlled by TC_MAX_TRIES. Default: 120.
Implementation
final int maxTries;
Maximum number of polling attempts before a wait strategy gives up.
Controlled by TC_MAX_TRIES. Default: 120.
final int maxTries;