Transferable class sealed

Base type for content that can be copied into a running container.

Use one of the two concrete sub-types:

Instances are created by the caller and passed to DockerContainer.withCopyIntoContainer or DockerContainer.copyIntoContainer.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited