containerInfo abstract method

Future<ContainerInspectInfo?> containerInfo()

Returns the full Docker inspect information for this container.

The result is lazily loaded and cached by most implementations. Returns null when the container has not yet been started or when the inspect call fails.

Implementation

Future<ContainerInspectInfo?> containerInfo();