exec abstract method

Future<(int, Uint8List)> exec(
  1. List<String> command
)

Runs command inside the container and returns its exit code and output.

Returns (exitCode, combinedOutputBytes). Implementations may combine stdout and stderr into a single byte buffer.

Throws StateError when called before the container is started, or when the target does not have an exec capability.

Implementation

Future<(int, Uint8List)> exec(List<String> command);