labelSessionId top-level constant

String const labelSessionId

Label key carrying the unique session identifier.

Its value is the process-scoped sessionId UUID. The Reaper uses this label to find and remove all resources belonging to the current test process after the process exits.

Implementation

const String labelSessionId = 'org.testcontainers.session-id';