sessionId top-level property

String sessionId
final

A UUID that is unique to the current Dart process.

Created once at module initialisation and reused for every container, network, and image created during the lifetime of the process. The Reaper (ryuk) registers this session ID so that Docker resources are removed when the process terminates.

Implementation

final String sessionId = const Uuid().v4();