tcVersion top-level constant

String const tcVersion

The current version of this Dart testcontainers library.

Hardcoded constant — must be kept in sync with the version field in packages/testcontainers/pubspec.yaml on every release. Stamped on every container, network, and image resource via labelVersion.

Implementation

const String tcVersion = '0.1.0';