testcontainersConfig top-level property

TestcontainersConfiguration testcontainersConfig
final

The process-wide testcontainers configuration singleton.

Constructed once at module initialisation by reading environment variables and ~/.testcontainers.properties. All library internals read their defaults from this object.

You can mutate individual fields (e.g. TestcontainersConfiguration.ryukDisabled) to influence behaviour without restarting the process.

Implementation

final testcontainersConfig = TestcontainersConfiguration();