throwStopIteration function

void throwStopIteration()

Throws _StopIteration to signal that the poll loop should stop immediately without waiting for the timeout.

Used by ContainerStatusWaitStrategy when the container enters an unexpected state (e.g. 'exited' or 'dead') from which it cannot recover.

Implementation

void throwStopIteration() => throw _StopIteration();