BytesTransferable class
Wraps raw bytes to be copied into a container.
The bytes are packed as a single file entry inside a tar archive and
placed at the destination path within the container.
Example:
container.withCopyIntoContainer(
BytesTransferable(Uint8List.fromList(utf8.encode('hello'))),
'/app/hello.txt',
0x1A4, // 0o644
);
- Inheritance
-
- Object
- Transferable
- BytesTransferable
Constructors
- BytesTransferable(Uint8List bytes)
-
Creates a BytesTransferable from
bytes.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited