ContainerBindOptions class
Mount propagation options for a bind mount.
Constructors
- ContainerBindOptions({String? propagation, bool? nonRecursive, bool? createMountpoint, bool? readOnlyNonRecursive, bool? readOnlyForceRecursive})
-
Creates a ContainerBindOptions with the given fields.
const
-
ContainerBindOptions.fromJson(Map<
String, dynamic> json) -
Deserialises from Docker's JSON representation.
factory
Properties
- createMountpoint → bool?
-
Whether to create the mount point if it does not exist.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nonRecursive → bool?
-
Whether to disable recursive bind mounts.
final
- propagation → String?
-
Propagation mode:
'private','rprivate','shared','rshared','slave', or'rslave'.final - readOnlyForceRecursive → bool?
-
Whether to force a recursive read-only bind mount.
final
- readOnlyNonRecursive → bool?
-
Whether the bind mount is non-recursively read-only.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited