ContainerDeviceMapping class
A host device exposed inside the container.
Constructors
- ContainerDeviceMapping({String? pathOnHost, String? pathInContainer, String? cgroupPermissions})
-
Creates a ContainerDeviceMapping with the given fields.
const
-
ContainerDeviceMapping.fromJson(Map<
String, dynamic> json) -
Deserialises from Docker's JSON representation.
factory
Properties
- cgroupPermissions → String?
-
cgroup device permissions string, e.g.
'rwm'.final - hashCode → int
-
The hash code for this object.
no setterinherited
- pathInContainer → String?
-
Path under which the device appears inside the container.
final
- pathOnHost → String?
-
Path to the device on the host.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited