ContainerGraphDriver class
The storage driver and its metadata for a container's writable layer.
Constructors
-
ContainerGraphDriver({String? name, Map<
String, String> ? data}) -
Creates a ContainerGraphDriver with the given fields.
const
-
ContainerGraphDriver.fromJson(Map<
String, dynamic> json) -
Deserialises from Docker's JSON representation.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited