ContainerImageManifestDescriptor class
Describes a layer in an image manifest (OCI image spec).
Constructors
-
ContainerImageManifestDescriptor({String? mediaType, String? digest, int? size, List<
String> ? urls, Map<String, String> ? annotations, Object? data, ContainerPlatform? platform, String? artifactType}) -
Creates a ContainerImageManifestDescriptor with the given fields.
const
-
ContainerImageManifestDescriptor.fromJson(Map<
String, dynamic> json) -
Deserialises a ContainerImageManifestDescriptor from Docker's JSON.
factory
Properties
-
annotations
→ Map<
String, String> ? -
Arbitrary annotations attached to this manifest descriptor.
final
- artifactType → String?
-
OCI artifact type string, if applicable.
final
- data → Object?
-
Embedded content data (rarely used).
final
- digest → String?
-
Content-addressable digest (
sha256:…).final - hashCode → int
-
The hash code for this object.
no setterinherited
- mediaType → String?
-
MIME type of the manifest or layer.
final
- platform → ContainerPlatform?
-
Platform information for multi-arch images.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int?
-
Size in bytes of the referenced object.
final
-
urls
→ List<
String> ? -
List of URLs where the content can be obtained.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited