ContainerLogConfig class
Logging driver configuration for a container.
Constructors
-
ContainerLogConfig({String? type, Map<
String, String> ? config}) -
Creates a ContainerLogConfig with the given fields.
const
-
ContainerLogConfig.fromJson(Map<
String, dynamic> json) -
Deserialises from Docker's JSON representation.
factory
Properties
-
config
→ Map<
String, String> ? -
Driver-specific configuration options.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
Log driver name, e.g.
'json-file','syslog','none'.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited