ContainerRestartPolicy class
The restart policy applied to a container.
Constructors
- ContainerRestartPolicy({String? name, int? maximumRetryCount})
-
Creates a ContainerRestartPolicy with the given fields.
const
-
ContainerRestartPolicy.fromJson(Map<
String, dynamic> json) -
Deserialises from Docker's JSON representation.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maximumRetryCount → int?
-
Maximum number of restart attempts (meaningful for
'on-failure').final - name → String?
-
Policy name:
'no','always','on-failure', or'unless-stopped'.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited