ContainerVolumeOptions class
Options for a volume mount.
Constructors
-
ContainerVolumeOptions({bool? noCopy, Map<
String, String> ? labels, ContainerVolumeDriverConfig? driverConfig, String? subpath}) -
Creates a ContainerVolumeOptions with the given fields.
const
-
ContainerVolumeOptions.fromJson(Map<
String, dynamic> json) -
Deserialises from Docker's JSON representation.
factory
Properties
- driverConfig → ContainerVolumeDriverConfig?
-
Volume driver configuration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
→ Map<
String, String> ? -
Labels applied to the volume.
final
- noCopy → bool?
-
When
true, disables copying data from the container path to the volume on first use.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subpath → String?
-
Sub-path within the volume to mount.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited