dockerClient property
DockerClient
get
dockerClient
Returns the underlying DockerClient instance.
Useful when a test or subclass needs to make additional Docker API calls that are not exposed directly on DockerContainer.
Implementation
DockerClient get dockerClient => _dockerClient;