withCopyIntoContainer method
Schedules transferable to be copied into the container at destination
with Unix permission mode when start is called.
The copy happens after the container is created but before start invokes the wait strategy.
Returns this for chaining.
Implementation
DockerContainer withCopyIntoContainer(
Transferable transferable,
String destination,
int mode,
) {
_transferableSpecs.add((transferable, destination, mode));
return this;
}