exposedPort abstract method
Returns the host-side port that is mapped to the container's port.
For connection modes that use mapped ports, this queries the Docker
daemon for the ephemeral port assigned by the host OS. For bridgeIp
mode, port is returned unchanged.
Implementation
Future<int> exposedPort(int port);