notExitedStatuses top-level constant
Container statuses that indicate the container is still alive and worth continuing to poll.
If WaitStrategyTarget.status is NOT in this set and a wait strategy has not yet succeeded, the strategy raises a StateError instead of waiting for the timeout.
Implementation
const Set<String> notExitedStatuses = {'running', 'created'};