testcontainersNamespace top-level constant
String
const testcontainersNamespace
The root namespace for all testcontainers Docker labels.
Any user-supplied label key that starts with this prefix is rejected by createLabels because those keys are reserved for internal use.
Implementation
const String testcontainersNamespace = 'org.testcontainers';